FrameHandle

Struct FrameHandle 

pub struct FrameHandle<FRAME> { /* private fields */ }
Handle to frame is returned when adding it to the view manager. Can be used to add listeners. (And potentially other manipulations of the frame are possible in the future)

Implementations

Source

impl<STATE: 'static, FRAME: Frame<State = STATE>> FrameHandle<FRAME>

pub fn listen<F, MSG>(&self, f: F)
where F: Fn(&mut FRAME, &mut STATE, &MSG) + Copy + 'static, MSG: 'static, FRAME: 'static,

Source

impl<STATE: 'static, FRAME: Frame<State = STATE>> FrameHandle<FRAME>

pub fn register_receiver<F, MSG>(&self, f: F)
where F: Fn(&mut FRAME, &mut STATE, MSG) + Copy + 'static, MSG: 'static, FRAME: 'static,

Source

impl<FRAME> FrameHandle<FRAME>

pub fn new( activity_id: ActivityId<FRAME>, div: DivHandle, region: Rectangle, ) -> Self

pub fn activity(&self) -> ActivityId<FRAME>

pub fn div(&self) -> &DivHandle

pub fn region(&self) -> Rectangle

pub fn set_z(&self, z: i32)

Define z-index property of HTML.

This might be necessary to ensure user input is processed by the intended frame. Drawing order for WebGL is not affected.