pub struct FrameHandle<FRAME> { /* private fields */ }Expand description
Handle to frame is returned when adding it to the view manager. Can be used to add listeners. (And potentially other manipulations of the frame are possible in the future)
Implementations
Sourceimpl<STATE: 'static, FRAME: Frame<State = STATE>> FrameHandle<FRAME>
impl<STATE: 'static, FRAME: Frame<State = STATE>> FrameHandle<FRAME>
Sourceimpl<STATE: 'static, FRAME: Frame<State = STATE>> FrameHandle<FRAME>
impl<STATE: 'static, FRAME: Frame<State = STATE>> FrameHandle<FRAME>
pub fn register_receiver<F, MSG>(&self, f: F)